/*
Copyright (c) Daybrush
name: react-scenejs
license: MIT
author: Daybrush
repository: https://github.com/daybrush/scenejs.git
version: 2.0.0-beta.14
*/
import { useReactive } from '@cfcs/react';
import { SCENE_REACTIVE, SCENE_ITEM_REACTIVE, FRAME_REACTIVE, NOW_FRAME_REACTIVE } from 'scenejs';
export * from 'scenejs';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

/**
 * @memberof ReactScene
 * @param {Reactive.SceneReactiveProps} - Items and properties that make up the scene
 * @param - Scene and Animator options
 * @return - You can use Scene methods and Animator State
 * @example
 * import { useScene, useNowFrame } from "react-scenejs";
 *
 * const scene = useScene({ ... });
 * const frame = useNowFrame(scene.getItem("a1"));
 *
 * frame.camelCasedCSSObject;
 */
function useScene(props, options) {
    return useReactive(__assign(__assign({}, SCENE_REACTIVE), { data: function () {
            return {
                props: props,
                options: options,
            };
        } }));
}

/**
 * @memberof ReactScene
 * @param {Reactive.SceneItemReactiveProps} - Items and properties that make up the scene item
 * @param - SceneItem and Animator options
 * @return - You can use SceneItem methods and Animator State.
 * @example
 * import { useSceneItem, useNowFrame } from "react-scenejs";
 *
 * const item = useSceneItem({ ... });
 * const frame = useNowFrame(item);
 *
 * frame.camelCasedCSSObject;
 */
function useSceneItem(props, options) {
    return useReactive(__assign(__assign({}, SCENE_ITEM_REACTIVE), { data: function () { return ({
            props: props,
            options: options,
        }); } }));
}

/**
 * @memberof ReactScene
 * @param {Reactive.FrameReactiveData} - Can be used as frame, cssText, cssObject, etc.
 * @return - You can use Frame methods and cssText, cssObject, ...etc
 * @example
 * import { useFrame } from "react-scenejs";
 *
 * const frame = useFrame("text-align: center; transform: translate(10px, 10px);");
 *
 * frame.camelCasedCSSObject;
 */
function useFrame(props) {
    return useReactive(__assign(__assign({}, FRAME_REACTIVE), { data: function () { return props; } }));
}

/**
 * @memberof ReactScene
 * @param  - item to get the current frame
 * @return - You can use Frame methods and cssText, cssObject, ...etc State
 * @example
 * import { useSceneItem, useNowFrame } from "react-scenejs";
 *
 * const sceneItem = useSceneItem(...);
 * const frame = useNowFrame(sceneItem);
 *
 * frame.camelCasedCSSObject;
 */
function useNowFrame(item) {
    return useReactive(__assign(__assign({}, NOW_FRAME_REACTIVE), { data: function () { return item; } }));
}

export { useFrame, useNowFrame, useScene, useSceneItem };
//# sourceMappingURL=scene.esm.js.map
